==> com.liferay.dynamic.data.mapping.form.builder-2.0.31.jar: META-INF/resources/js/components/LayoutProvider/handlers/fieldMovedHandler.es.js <==
"use strict";

Liferay.Loader.define("dynamic-data-mapping-form-builder@2.0.31/js/components/LayoutProvider/handlers/fieldMovedHandler.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  var FormSupport = _interopRequireWildcard(require("dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es"));

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj.default = obj;return newObj;
    }
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var _default = function _default(props, state, _ref) {
    var addedToPlaceholder = _ref.addedToPlaceholder,
        source = _ref.source,
        target = _ref.target;
    var pages = state.pages;
    var columnIndex = source.columnIndex,
        pageIndex = source.pageIndex,
        rowIndex = source.rowIndex;
    var column = FormSupport.getColumn(pages, pageIndex, rowIndex, columnIndex);
    var fields = column.fields;
    var newRow = FormSupport.implAddRow(12, fields);
    pages = FormSupport.removeFields(pages, pageIndex, rowIndex, columnIndex);

    if (target.rowIndex > pages[pageIndex].rows.length - 1 || addedToPlaceholder) {
      pages = FormSupport.addRow(pages, target.rowIndex, target.pageIndex, newRow);
    } else {
      pages = FormSupport.addFieldToColumn(pages, target.pageIndex, target.rowIndex, target.columnIndex, fields[0]);
    }

    pages[pageIndex].rows = FormSupport.removeEmptyRows(pages, pageIndex);
    return {
      pages: pages
    };
  };

  exports.default = _default;
  //# sourceMappingURL=fieldMovedHandler.es.js.map
});
//# sourceMappingURL=fieldMovedHandler.es.js.map

==> com.liferay.dynamic.data.mapping.form.builder-2.0.34.jar: META-INF/resources/js/components/LayoutProvider/handlers/fieldMovedHandler.es.js <==
"use strict";

Liferay.Loader.define("dynamic-data-mapping-form-builder@2.0.34/js/components/LayoutProvider/handlers/fieldMovedHandler.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var FormSupport = _interopRequireWildcard(require("dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es"));

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var _default = function _default(props, state, _ref) {
    var addedToPlaceholder = _ref.addedToPlaceholder,
        source = _ref.source,
        target = _ref.target;
    var pages = state.pages;
    var columnIndex = source.columnIndex,
        pageIndex = source.pageIndex,
        rowIndex = source.rowIndex;
    var column = FormSupport.getColumn(pages, pageIndex, rowIndex, columnIndex);
    var fields = column.fields;
    var newRow = FormSupport.implAddRow(12, fields);
    pages = FormSupport.removeFields(pages, pageIndex, rowIndex, columnIndex);

    if (target.rowIndex > pages[pageIndex].rows.length - 1 || addedToPlaceholder) {
      pages = FormSupport.addRow(pages, target.rowIndex, target.pageIndex, newRow);
    } else {
      pages = FormSupport.addFieldToColumn(pages, target.pageIndex, target.rowIndex, target.columnIndex, fields[0]);
    }

    pages[pageIndex].rows = FormSupport.removeEmptyRows(pages, pageIndex);
    return {
      pages: pages
    };
  };

  exports["default"] = _default;
  //# sourceMappingURL=fieldMovedHandler.es.js.map
});
//# sourceMappingURL=fieldMovedHandler.es.js.map
